@@ -12,16 +12,18 @@ def get_parser():
                                                  download output metadata for scattering"
     )
     parser.add_argument(
+        "-m",
         "--accession-metadata",
-        type=str,
-        default=None,
-        help="path to a metadata json output file",
+        help="path to a metadata json file or a Caper workflow ID/label",
+        required=True,
     )
     parser.add_argument(
+        "-p",
         "--pipeline-type",
         type=str,
         default=None,
-        help=f"the type of pipeline run being accessioned, e.g. mirna or long_read_rna",
+        help="the type of pipeline run being accessioned, e.g. mirna or long_read_rna",
+        required=True,
     )
     parser.add_argument(
         "-d",
@@ -30,7 +32,11 @@ def get_parser():
         help="Perform a dry run for accessioning, not post anything.",
     )
     parser.add_argument(
-        "--server", default="dev", help="Server the files will be accessioned to"
+        "-s",
+        "--server",
+        default="dev",
+        help="Server the files will be accessioned to",
+        required=True,
     )
     parser.add_argument(
         "--no-log-file",
@@ -84,19 +90,16 @@ def main():
     parser = get_parser()
     args = parser.parse_args()
     lab, award = check_or_set_lab_award(args.lab, args.award)
-    if all([args.pipeline_type, args.accession_metadata, lab, award, args.server]):
-        accessioner = accession_factory(
-            args.pipeline_type,
-            args.accession_metadata,
-            args.server,
-            lab,
-            award,
-            log_file_path=args.log_file_path,
-            no_log_file=args.no_log_file,
-        )
-        accessioner.accession_steps(args.dry_run)
-        return
-    print("Module called without proper arguments")
+    accessioner = accession_factory(
+        args.pipeline_type,
+        args.accession_metadata,
+        args.server,
+        lab,
+        award,
+        log_file_path=args.log_file_path,
+        no_log_file=args.no_log_file,
+    )
+    accessioner.accession_steps(args.dry_run)
 
 
 if __name__ == "__main__":
