@@ -9,13 +9,14 @@ from requests import Response
 from accession.accession import (
     Accession,
     AccessionBulkRna,
-    AccessionLongReadRna,
     AccessionMicroRna,
+    _get_long_read_rna_steps_json_name_prefix_from_metadata,
     accession_factory,
 )
-from accession.accession_steps import AccessionStep
+from accession.accession_steps import AccessionStep, DerivedFromFile
 from accession.encode_models import EncodeExperiment, EncodeFile
 from accession.file import GSFile
+from accession.metadata import FileMetadata
 from accession.preflight import MatchingMd5Record
 from accession.task import Task
 
@@ -172,6 +173,30 @@ def test_get_all_encode_files_matching_md5_of_blob_cache_hit_no_results_returns_
     assert result is None
 
 
+def test_filter_derived_from_files_by_workflow_inputs(mocker, mock_accession):
+    mocker.patch.object(
+        mock_accession.analysis,
+        "metadata",
+        new_callable=mocker.PropertyMock(
+            return_value={"inputs": {"foo": ["gs://bar/baz"]}}
+        ),
+    )
+    ancestor = DerivedFromFile(
+        {
+            "workflow_inputs_to_match": ["foo"],
+            "derived_from_filekey": "foo",
+            "derived_from_task": "task",
+        }
+    )
+    file_to_match = GSFile(key="foo", name="gs://bar/baz", md5sum="123", size=456)
+    file_to_ignore = GSFile(key="baz", name="gs://bar/qux", md5sum="123", size=456)
+    derived_from_files = [file_to_match, file_to_ignore]
+    result = mock_accession._filter_derived_from_files_by_workflow_inputs(
+        derived_from_files, ancestor
+    )
+    assert result == [file_to_match]
+
+
 def test_make_file_matching_md5_record_no_matches_returns_none(
     mocker, mock_accession, mock_file
 ):
@@ -404,18 +429,25 @@ def test_accession_init(mock_accession: Accession, lab: str, award: str) -> None
     "pipeline_type,condition,accessioner_class",
     [
         ("mirna", does_not_raise(), AccessionMicroRna),
-        ("long_read_rna", does_not_raise(), AccessionLongReadRna),
         ("bulk_rna", does_not_raise(), AccessionBulkRna),
         ("not_valid", pytest.raises(RuntimeError), None),
     ],
 )
 def test_accession_factory(
-    mocker, mock_gc_backend, server_name, pipeline_type, condition, accessioner_class
+    tmp_path,
+    mocker,
+    mock_gc_backend,
+    server_name,
+    pipeline_type,
+    condition,
+    accessioner_class,
 ):
     """
     The Connection class actually tries to make connections to the server within its
     __init__, so need to mock out.
     """
+    metadata_file = tmp_path / "metadata.json"
+    metadata_file.touch()
     mocker.patch(
         "builtins.open",
         mocker.mock_open(read_data='{"workflowRoot": "gs://foo/bar", "calls": {}}'),
@@ -424,7 +456,7 @@ def test_accession_factory(
     with condition:
         accessioner = accession_factory(
             pipeline_type,
-            "metadata.json",
+            str(metadata_file),
             server_name,
             "baz",
             "qux",
@@ -432,3 +464,29 @@ def test_accession_factory(
             no_log_file=True,
         )
         assert isinstance(accessioner, accessioner_class)
+
+
+@pytest.mark.parametrize(
+    "spikeins,expected",
+    [
+        ([], "long_read_rna_no_spikeins"),
+        (["foo"], "long_read_rna_one_spikein"),
+        (["foo", "bar"], "long_read_rna_two_or_more_spikeins"),
+    ],
+)
+def test_get_long_read_rna_steps_json_name_prefix_from_metadata(
+    tmp_path, mocker, spikeins, expected
+):
+    mocker.patch(
+        "accession.metadata.FileMetadata.content",
+        new_callable=mocker.PropertyMock(
+            return_value={
+                "workflowRoot": "gs://foo/bar",
+                "calls": {},
+                "inputs": {"spikeins": spikeins},
+            }
+        ),
+    )
+    metadata = FileMetadata("foo")
+    result = _get_long_read_rna_steps_json_name_prefix_from_metadata(metadata)
+    assert result == expected
